import logging
from dataclasses import dataclass
from dataclasses import field
from dataclasses import InitVar

import gget

from snprimer.position_range import PositionRange


@dataclass
class Primer:
    seq: str
    position_ranges: list[PositionRange] = field(default_factory=list)
    ref_version: InitVar[str] = "hg38"

    def __post_init__(self, ref_version):
        if len(self.seq) <= 20:
            logging.warning(f"Primer {self}is too small to apply the blast and therefore to get information")
        else:
            self._make_blast(ref_version)

    def _make_blast(self, ref_version: str):
        for hit in gget.blat(self.seq, seqtype="DNA", assembly=ref_version, json=True):
            self.position_ranges.append(
                PositionRange(hit["chromosome"], hit["start"], hit["end"], hit["strand"], init_snp=True)
            )

    def infos(self, max_vaf=0.1):  # TODO Remove (dont forget README)
        is_ok = True
        if len(self.position_ranges) > 1:
            is_ok = False
            print(f"{self.seq} has multiple potential hybridation sites in the genome.")
        for position_range in self.position_ranges:
            true_snp = position_range.get_snp(max_vaf)
            if true_snp:
                print(f"{self.seq} has snp with vaf > {max_vaf} : {true_snp} ")
                is_ok = False
        if is_ok:
            print(f"{self.seq} is ok")


if __name__ == "__main__":
    a = Primer("CACACAGATCAGAGGGCCAAC")
    a.infos(0)



from pathlib import Path

import tomllib


def get_version():
    path = Path(__file__).resolve().parents[1] / "pyproject.toml"
    pyproject = tomllib.loads(open(str(path)).read())
    return pyproject["tool"]["poetry"]["version"]


__version__ = get_version()



from dataclasses import dataclass
from dataclasses import InitVar


@dataclass
class SNP:
    id: str
    rsid: str
    alleles: InitVar[list]
    ref: InitVar[str]
    vaf: float = 0

    def __post_init__(self, alleles, ref):
        for allele in alleles:
            if allele["allele"] == ref:
                self.vaf = self._get_vaf(allele["freq"])

    @staticmethod
    def _get_vaf(allele_freq):
        for key in ["1000g", "exac", "gnomad", "gnomad_exomes", "topmed"]:  # top db
            if allele_freq.get(key):
                return 1 - allele_freq.get(key)
        return 0  # If no match we can estimate the vaf is nul.



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['snprimer']

package_data = \
{'': ['*']}

install_requires = \
['bump2version>=1.0.1,<2.0.0',
 'click>=8.1.3,<9.0.0',
 'gget>=0.3.11,<0.4.0',
 'myvariant>=1.0.0,<2.0.0',
 'pre-commit>=2.20.0,<3.0.0']

setup_kwargs = {
    'name': 'snprimer',
    'version': '0.1.1',
    'description': 'Small python library to search snp in primer by position or by sequence.',
    'long_description': '# SNPrimer\n\nSmall python library to search snp in primer by position or by sequence.\n\n## Installation\n\n`pip install snprimer``\n\n## Usage\n\n### 🎯 By position 🎯\n\n```python\nfrom snprimer import PositionRange\n\nposition = PositionRange("chr8",19818430, 19818440)\nprint(position)\n# PositionRange(chr=\'chr8\', start=19818430, end=19818440, strand=None, snp=[SNP(id=\'chr8:g.19818436C>G\', rsid=\'rs316\', vaf=0.15300000000000002), SNP(id=\'chr8:g.19818436C>T\', rsid=\'rs316\', vaf=0.15300000000000002)])\nfor snp in position.get_snp(max_vaf=0.05):\n    print(snp)\n#SNP(id=\'chr8:g.19818436C>G\', rsid=\'rs316\', vaf=0.15300000000000002)\n#SNP(id=\'chr8:g.19818436C>T\', rsid=\'rs316\', vaf=0.15300000000000002)\n```\n\n### 🔤 By sequence 🔤\n```python\nfrom snprimer import Primer\n\nprimer = Primer("CACACAGATCAGAGGGCCAAC")\nprint(primer)\n#Primer(seq=\'CACACAGATCAGAGGGCCAAC\', position_ranges=[PositionRange(chr=\'chr1\', start=26774827, end=26774847, strand=\'+\', snp=[SNP(id=\'chr1:g.26774827G>A\', rsid=\'rs2075289787\', vaf=0), SNP(id=\'chr1:g.26774830A>G\', rsid=\'rs986550282\', vaf=0.0), SNP(id=\'chr1:g.26774842T>C\', rsid=\'rs1440652363\', vaf=0.0)])])\nprimer.infos(max_vaf=0)\n#CACACAGATCAGAGGGCCAAC has snp with vaf > 0 : [SNP(id=\'chr1:g.26774827G>A\', rsid=\'rs2075289787\', vaf=0), SNP(id=\'chr1:g.26774830A>G\', rsid=\'rs986550282\', vaf=0.0), SNP(id=\'chr1:g.26774842T>C\', rsid=\'rs1440652363\', vaf=0.0)]\n```\n',
    'author': 'Benoitdw',
    'author_email': 'bw@oncodna.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/Benoitdw/SNPrimer',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)
